@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aws
 version: 0.13.0
-id: aws-0.13.0-683f437f93d5c0d59e9acd2d465eb64e
-key: aws_ID22DoFwRQdAuXqh7sUg9K
+id: aws-0.13.0-f08bddca20a80ffa9946fd4ac0a95a31
+key: aws_2MCeqgPoamsJfGJDJIhvYQ
 license: BSD3
 copyright: See contributors list in README and LICENSE file
 maintainer: aristidb@gmail.com
@@ -55,7 +55,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aws-0.13.0
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aws-0.13.0
-hs-libraries: HSaws-0.13.0-ID22DoFwRQdAuXqh7sUg9K
+hs-libraries: HSaws-0.13.0-2MCeqgPoamsJfGJDJIhvYQ
 depends:
     aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
@@ -68,13 +68,13 @@ depends:
     case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
     cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
     conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
-    conduit-extra-1.1.13.1-eddf025ec4463f8bba96cb21182c4b0f
+    conduit-extra-1.1.13.1-cf2e2742d7d01907ed25c65d155b9a5e
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     cryptohash-0.11.9-1ce6a3e7b661f39b36d188b8c49a9b44
     data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
-    http-conduit-2.1.10.1-25cf7e0ab425a3f9a6e4adec2d684722
+    http-conduit-2.1.10.1-06d6cae4a7dc7e652455c24a41eb9def
     http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
     lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
     monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
@@ -91,7 +91,7 @@ depends:
     unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    xml-conduit-1.3.4.2-dfa752a9941da549533f5136393fb800
+    xml-conduit-1.3.5-b0d7925ea0f1a62fe18b3cdd25dd3416
 haddock-interfaces: /usr/share/doc/haskell-aws/html/aws.haddock
 haddock-html: /usr/share/doc/haskell-aws/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
